<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => 'افتراضياً، يتم إضفاء صندوق الفرجة على كل الوصلات الى الصور (لها نوع خاصية يصف mime/type الصورة) إضافة الى الوصلات المزودة بنمط &lt;code&gt;.mediabox&lt;/code&gt;.



من الممكن إعداد كل وصلة على حدة من خلال أنماط إضافية:

-* يتيح &lt;code&gt;boxIframe&lt;/code&gt;  فتح الوصلة في إطار iframe

-* يتيج &lt;code&gt;boxWidth-350px&lt;/code&gt; تحديد عرض ٣٥٠ نقطة للإطار

-* يتيح &lt;code&gt;boxHeight-90pc&lt;/code&gt; تحديد ارتفاع ٩٠٪ للإطار



وتتيح لوحة تحكم تعديل الإعدادات العامة حسب الرغبة كما تتيح اختيار شكل الصندوق من بين الأشكال المتاحة.

يعمل هذا الملحق في الصفحات النموذجية التي تحتوي على علامة <code>#INSERT_HEAD</code>',
	'mediabox_nom' => 'صندوق الفرجة',
	'mediabox_slogan' => 'صندوق الفرجة',
];
